@@ -1,4 +1,4 @@
-from typing import Any, List, Type
+from typing import Any, List, Type, Dict, Optional
 
 import numpy as np
 
@@ -7,6 +7,8 @@ from .tensorflow_proto.tensorflow.core.framework import (
     tensor_shape_pb2,
     types_pb2,
 )
+from .exceptions import PythieServingException
+
 
 # from https://github.com/tensorflow/tensorflow/blob/master/tensorflow/python/framework/dtypes.py
 _TF_TO_NP = {
@@ -32,6 +34,12 @@ _NP_TO_TF = {nt: tt for tt, nt in _TF_TO_NP.items()}
 _NP_TO_TF[np.bytes_] = types_pb2.DT_STRING
 _NP_TO_TF[np.str_] = types_pb2.DT_STRING
 
+_CSV_TYPE = {
+    "int": int,
+    "str": lambda x: bytes(x, 'utf-8'),
+    "bool": bool,
+}
+
 
 def get_tf_type(np_dtype: Type):
     """
@@ -120,3 +128,42 @@ def make_ndarray_from_tensor(tensor: tensor_pb2.TensorProto):
         values = np.pad(values, (0, num_elements - values.size), "edge")
 
     return values.reshape(shape)
+
+
+def get_csv_type(type_mapping: Dict[str, str]):
+    try:
+        return {feature_name: _CSV_TYPE[data_type] for feature_name, data_type in type_mapping.items()}
+    except KeyError:
+        raise TypeError(f"Could not infer conversion type given {type_mapping}. "
+                        f"Expecting one of following types: {_CSV_TYPE.keys()}")
+
+
+def parse_sample(request_inputs, features_names: List[str], nb_features: int, samples_dtype: Optional[Any] = None):
+    for feature_name in features_names:
+        check_request_feature_exists(request_inputs, feature_name)
+
+    nb_samples = request_inputs[features_names[0]].tensor_shape.dim[0].size
+    samples = np.empty((nb_samples, nb_features), samples_dtype)
+
+    for feature_index, feature_name in enumerate(features_names):
+        check_request_valid_length(request_inputs, feature_name, nb_samples)
+        nd_array = make_ndarray_from_tensor(request_inputs[feature_name])
+        check_array_shape(nd_array)
+
+        samples[:, feature_index] = nd_array.reshape(-1)
+    return samples
+
+
+def check_request_valid_length(request_inputs, feature_name: str, nb_samples: int):
+    if request_inputs[feature_name].tensor_shape.dim[0].size != nb_samples:
+        raise PythieServingException(f"{feature_name} has invalid length.")
+
+
+def check_array_shape(nd_array: np.ndarray):
+    if len(nd_array.shape) != 2 or nd_array.shape[1] != 1:
+        raise PythieServingException("All input vectors should be 1D tensor")
+
+
+def check_request_feature_exists(request_inputs, feature_name: str):
+    if feature_name not in request_inputs:
+        raise PythieServingException(f"{feature_name} not set in the predict request.")
